@@ -7,7 +7,7 @@ from dataclasses import dataclass
 from datetime import UTC, datetime
 from http import HTTPStatus
 from http.cookies import SimpleCookie
-from typing import Any, cast
+from typing import Any, TypedDict, cast
 
 import aiohttp
 import pint
@@ -16,9 +16,7 @@ from yarl import URL
 from .const import (
     _LOGGER,
     ALARM_AREA_STATUS,
-    ALARM_AREAS,
     ALARM_ZONE_STATUS,
-    ALARM_ZONES,
     BRIDGE,
     CLIMATE,
     COVER,
@@ -47,7 +45,7 @@ class ComelitSerialBridgeObject:
     status: int
     human_status: str
     type: str
-    val: int | dict[Any, Any]  # Temperature or Humidity (CLIMATE)
+    val: int | list[dict[Any, Any]]  # Temperature or Humidity (CLIMATE)
     protected: int
     zone: str
     power: float
@@ -84,6 +82,13 @@ class ComelitVedoZoneObject:
     human_status: AlarmZoneState
 
 
+class AlarmDataObject(TypedDict):
+    """TypedDict for Alarm data objects."""
+
+    alarm_areas: dict[int, ComelitVedoAreaObject]
+    alarm_zones: dict[int, ComelitVedoZoneObject]
+
+
 class ComelitCommonApi:
     """Common API calls for Comelit SimpleHome devices."""
 
@@ -357,7 +362,7 @@ class ComelitCommonApi:
 
     async def get_all_areas_and_zones(
         self,
-    ) -> dict[str, dict[int, Any]]:
+    ) -> AlarmDataObject:
         """Get all VEDO system AREA and ZONE."""
         queries: dict[int, dict[str, Any]] = {
             1: {
@@ -412,7 +417,7 @@ class ComelitCommonApi:
             self._json_data.insert(index, reply_json)
 
         list_areas: list[int] = self._json_data[1]["present"]
-        areas = {}
+        areas: dict[int, ComelitVedoAreaObject] = {}
         for i in range(len(list_areas)):
             if not list_areas[i]:
                 _LOGGER.debug("Alarm skipping non present AREA [%i]", i)
@@ -425,7 +430,7 @@ class ComelitCommonApi:
             areas.update({i: area})
 
         list_zones: list[int] = self._json_data[2]["present"]
-        zones = {}
+        zones: dict[int, ComelitVedoZoneObject] = {}
         for i in range(len(list_zones)):
             if not int(list_zones[i]):
                 _LOGGER.debug("Alarm skipping non present ZONE [%i]", i)
@@ -437,7 +442,7 @@ class ComelitCommonApi:
             )
             zones.update({i: zone})
 
-        return {ALARM_AREAS: areas, ALARM_ZONES: zones}
+        return AlarmDataObject(alarm_areas=areas, alarm_zones=zones)
 
 
 class ComeliteSerialBridgeApi(ComelitCommonApi):
